Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/typedal/__about__.py | 1 | 0 | 0 | 100%
src/typedal/__init__.py | 5 | 0 | 2 | 100%
src/typedal/caching.py | 123 | 29 | 1 | 76%
src/typedal/core.py | 872 | 6 | 136 | 99%
src/typedal/fields.py | 85 | 0 | 0 | 100%
src/typedal/for_py4web.py | 16 | 0 | 12 | 100%
src/typedal/helpers.py | 79 | 0 | 0 | 100%
src/typedal/types.py | 59 | 0 | 0 | 100%
Total | 1240 | 35 | 151 | 97%

No items found using the specified filter.